==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/interceptors/tests/bindings/resolution/ejb/BallBindingLiteral.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.bindings.resolution.ejb;

import javax.enterprise.util.AnnotationLiteral;
import javax.inject.Named;

/**
 * Annotation literal for {@link Named}
 */
@SuppressWarnings("all")
public class BallBindingLiteral extends AnnotationLiteral<BallBinding> implements BallBinding {

    public static final BallBinding INSTANCE = new BallBindingLiteral(false, false);

    private boolean requiresBall;

    private boolean requiresPlayer;

    public BallBindingLiteral(boolean requiresBall, boolean requiresPlayer) {
        super();
        this.requiresBall = requiresBall;
        this.requiresPlayer = requiresPlayer;
    }

    @Override
    public boolean requiresBall() {
        return requiresBall;
    }

    @Override
    public boolean requiresPlayer() {
        return requiresPlayer;
    }

}

==> cdi-tck-4.0.9-dist.zip: org/jboss/cdi/tck/interceptors/tests/bindings/resolution/ejb/BallBindingLiteral.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.bindings.resolution.ejb;

import jakarta.enterprise.util.AnnotationLiteral;
import jakarta.inject.Named;

/**
 * Annotation literal for {@link Named}
 */
@SuppressWarnings("all")
public class BallBindingLiteral extends AnnotationLiteral<BallBinding> implements BallBinding {

    public static final BallBinding INSTANCE = new BallBindingLiteral(false, false);

    private boolean requiresBall;

    private boolean requiresPlayer;

    public BallBindingLiteral(boolean requiresBall, boolean requiresPlayer) {
        super();
        this.requiresBall = requiresBall;
        this.requiresPlayer = requiresPlayer;
    }

    @Override
    public boolean requiresBall() {
        return requiresBall;
    }

    @Override
    public boolean requiresPlayer() {
        return requiresPlayer;
    }

}
